pub enum Error {
Io(Error),
Rpc(Error),
NoFeature,
NoEnvVar,
NoBitcoindExecutableFound,
EarlyExit(ExitStatus),
BothDirsSpecified,
RpcUserAndPasswordUsed,
SkipDownload,
NoBitcoindInstance(String),
}Expand description
All the possible error in this crate.
Variants
Io(Error)
Wrapper of io Error.
Rpc(Error)
Wrapper of bitcoincore_rpc Error.
NoFeature
Returned when calling methods requiring a feature to be activated, but it’s not.
NoEnvVar
Returned when calling methods requiring a env var to exist, but it’s not.
NoBitcoindExecutableFound
Returned when calling methods requiring the bitcoind executable but none is found
(no feature, no BITCOIND_EXE, no bitcoind in PATH ).
EarlyExit(ExitStatus)
Wrapper of early exit status.
BothDirsSpecified
Returned when both tmpdir and staticdir is specified in Conf options.
RpcUserAndPasswordUsed
Returned when -rpcuser and/or -rpcpassword is used in Conf args.
It will soon be deprecated, please use -rpcauth instead.
SkipDownload
Returned when expecting an auto-downloaded executable but BITCOIND_SKIP_DOWNLOAD env var is set.
NoBitcoindInstance(String)
Returned when bitcoind could not be reached after multiple attempts. The attached string, if present, contains the error encountered when trying to connect.