pub struct GetTransactionDetail {
pub involves_watch_only: Option<bool>,
pub account: Option<String>,
pub address: Address<NetworkUnchecked>,
pub category: TransactionCategory,
pub amount: SignedAmount,
pub label: Option<String>,
pub vout: u32,
pub fee: Option<SignedAmount>,
pub abandoned: Option<bool>,
pub parent_descriptors: Option<Vec<String>>,
}Expand description
Transaction detail. Part of the gettransaction.
Fields
involves_watch_only: Option<bool>Only returns true if imported addresses were involved in transaction. v20 and later only.
account: Option<String>DEPRECATED. The account name involved in the transaction, can be “” for the default account.
address: Address<NetworkUnchecked>The bitcoin address involved in the transaction.
category: TransactionCategoryThe category, either ‘send’ or ‘receive’.
amount: SignedAmountThe amount.
label: Option<String>A comment for the address/transaction, if any.
vout: u32the vout value.
fee: Option<SignedAmount>The amount of the fee.
This is negative and only available for the ‘send’ category of transactions.
abandoned: Option<bool>If the transaction has been abandoned (inputs are respendable).
Only available for the ‘send’ category of transactions.
parent_descriptors: Option<Vec<String>>Only if ‘category’ is ‘received’. List of parent descriptors for the output script of this coin. v24 and later only.