pub struct GetTxOutSetInfo {
pub height: u32,
pub best_block: BlockHash,
pub transactions: Option<u32>,
pub tx_outs: u32,
pub bogo_size: u32,
pub hash_serialized_2: Option<String>,
pub hash_serialized_3: Option<String>,
pub disk_size: Option<u32>,
pub total_amount: Amount,
pub muhash: Option<String>,
pub total_unspendable_amount: Option<Amount>,
pub block_info: Option<GetTxOutSetInfoBlockInfo>,
}Expand description
Models the result of JSON-RPC method gettxoutsetinfo.
Fields
height: u32The current block height (index).
best_block: BlockHashThe hash of the block at the tip of the chain.
transactions: Option<u32>The number of transactions with unspent outputs (not available when coinstatsindex is used).
tx_outs: u32The number of unspent transaction outputs.
bogo_size: u32A meaningless metric for UTXO set size.
hash_serialized_2: Option<String>The serialized hash.
This was removed in Bitcoin Core v26, and hence will be None for v26 and later.
hash_serialized_3: Option<String>The serialized hash (only present if ‘hash_serialized_3’ hash_type is chosen). v26 and later only.
disk_size: Option<u32>The estimated size of the chainstate on disk (not available when coinstatsindex is used).
total_amount: AmountThe total amount.
muhash: Option<String>The serialized hash (only present if ‘muhash’ hash_type is chosen).
total_unspendable_amount: Option<Amount>The total amount of coins permanently excluded from the UTXO set (only available if coinstatsindex is used).
block_info: Option<GetTxOutSetInfoBlockInfo>Info on amounts in the block at this block height (only available if coinstatsindex is used).