GetTxOutSetInfoBlockInfo

Struct GetTxOutSetInfoBlockInfo 

pub struct GetTxOutSetInfoBlockInfo {
    pub prevout_spent: Amount,
    pub coinbase: Amount,
    pub new_outputs_ex_coinbase: Amount,
    pub unspendable: Amount,
    pub unspendables: GetTxOutSetInfoUnspendables,
}
Detailed block-level info. Part of gettxoutsetinfo.

Fields

prevout_spent: Amount

Total amount of all prevouts spent in this block.

coinbase: Amount

Coinbase subsidy amount of this block.

new_outputs_ex_coinbase: Amount

Total amount of new outputs created by this block.

unspendable: Amount

Total amount of unspendable outputs created in this block.

unspendables: GetTxOutSetInfoUnspendables

Detailed view of unspendable categories.