pub enum ControlBlocksError {
Missing,
Multiple(usize),
Parse(HexToBytesError),
Decode(TaprootError),
}Expand description
Error when converting the control blocks vector.
Variants
Missing
No control block returned by Core for this script.
Multiple(usize)
Multiple control blocks returned by Core for this script.
Parse(HexToBytesError)
Failed to parse control block hex string.
Decode(TaprootError)
Failed to decode parsed bytes.