pub struct GetBalancesMine {
pub trusted: f64,
pub untrusted_pending: f64,
pub immature: f64,
pub used: Option<f64>,
}Expand description
Balances from outputs that the wallet can sign. Part of getbalances.
Fields
trusted: f64Trusted balance (outputs created by the wallet or confirmed outputs).
untrusted_pending: f64Untrusted pending balance (outputs created by others that are in the mempool).
immature: f64Balance from immature coinbase outputs.
used: Option<f64>Balance from coins sent to addresses that were previously spent from (potentially privacy violating).
Only present if avoid_reuse is set.
Implementations
Sourceimpl GetBalancesMine
impl GetBalancesMine
Sourcepub fn into_model(self) -> Result<GetBalancesMine, ParseAmountError>
pub fn into_model(self) -> Result<GetBalancesMine, ParseAmountError>
Converts version specific type to a version nonspecific, more strongly typed type.