pub struct GetNewAddress(pub String);Expand description
Result of the JSON-RPC method getnewaddress.
getnewaddress ( “label” “address_type” )
Returns a new Bitcoin address for receiving payments. If ‘label’ is specified, it is added to the address book so payments received with the address will be associated with ‘label’.
Tuple Fields
0: StringImplementations
Sourceimpl GetNewAddress
impl GetNewAddress
Sourcepub fn into_model(self) -> Result<GetNewAddress, ParseError>
pub fn into_model(self) -> Result<GetNewAddress, ParseError>
Converts version specific type to a version nonspecific, more strongly typed type.
Sourcepub fn address(self) -> Result<Address<NetworkUnchecked>, ParseError>
pub fn address(self) -> Result<Address<NetworkUnchecked>, ParseError>
Converts json straight to a bitcoin::Address.