pub struct GetTxSpendingPrevout(pub Vec<GetTxSpendingPrevoutItem>);Expand description
Result of JSON-RPC method gettxspendingprevout.
gettxspendingprevout [{“txid”:“hex”,“vout”:n},…]
Scans the mempool to find transactions spending any of the given outputs
Arguments:
- outputs (json array, required) The transaction outputs that we want to check, and within each, the txid (string) vout (numeric).
Tuple Fields
0: Vec<GetTxSpendingPrevoutItem>Implementations
Sourceimpl GetTxSpendingPrevout
impl GetTxSpendingPrevout
Sourcepub fn into_model(
self,
) -> Result<GetTxSpendingPrevout, GetTxSpendingPrevoutError>
pub fn into_model( self, ) -> Result<GetTxSpendingPrevout, GetTxSpendingPrevoutError>
Converts version specific type to a version nonspecific, more strongly typed type.