pub struct ListLockUnspent(pub Vec<ListLockUnspentItem>);Expand description
Result of the JSON-RPC method listlockunspent.
listlockunspent
Returns list of temporarily unspendable outputs. See the lockunspent call to lock and unlock transactions for spending.
Tuple Fields
0: Vec<ListLockUnspentItem>Implementations
Sourceimpl ListLockUnspent
impl ListLockUnspent
Sourcepub fn into_model(self) -> Result<ListLockUnspent, ListLockUnspentItemError>
pub fn into_model(self) -> Result<ListLockUnspent, ListLockUnspentItemError>
Converts version specific type to a version nonspecific, more strongly typed type.