pub struct Locked {
pub used: u64,
pub free: u64,
pub total: u64,
pub locked: u64,
pub chunks_used: u64,
pub chunks_free: u64,
}Expand description
Information about locked memory manager. Part of getmemoryinfo.
Fields
used: u64Number of bytes used.
free: u64Number of bytes available in current arenas.
total: u64Total number of bytes managed.
locked: u64Amount of bytes that succeeded locking.
If this number is smaller than total, locking pages failed at some point and key data could be swapped to disk.
chunks_used: u64Number allocated chunks.
chunks_free: u64Number unused chunks.