pub struct MempoolEntry {Show 14 fields
pub vsize: i64,
pub weight: i64,
pub time: i64,
pub height: i64,
pub descendant_count: i64,
pub descendant_size: i64,
pub ancestor_count: i64,
pub ancestor_size: i64,
pub wtxid: String,
pub fees: MempoolEntryFees,
pub depends: Vec<String>,
pub spent_by: Vec<String>,
pub bip125_replaceable: bool,
pub unbroadcast: bool,
}Expand description
Mempool data. Part of getmempoolentry.
Fields
vsize: i64Virtual transaction size as defined in BIP 141.
This is different from actual serialized size for witness transactions as witness data is discounted.
weight: i64Transaction weight as defined in BIP 141.
time: i64Local time transaction entered pool in seconds since 1 Jan 1970 GMT.
height: i64Block height when transaction entered pool.
descendant_count: i64Number of in-mempool descendant transactions (including this one).
descendant_size: i64Virtual transaction size of in-mempool descendants (including this one).
ancestor_count: i64Number of in-mempool ancestor transactions (including this one).
ancestor_size: i64Virtual transaction size of in-mempool ancestors (including this one).
wtxid: StringHash of serialized transaction, including witness data.
fees: MempoolEntryFeesFee object which contains the base fee, modified fee (with fee deltas), and ancestor/descendant fee totals all in BTC.
depends: Vec<String>Unconfirmed transactions used as inputs for this transaction (parent transaction id).
spent_by: Vec<String>Unconfirmed transactions spending outputs from this transaction (child transaction id).
bip125_replaceable: boolWhether this transaction signals BIP125 replaceability or has an unconfirmed ancestor signaling BIP125 replaceability.
unbroadcast: boolWhether this transaction is currently unbroadcast (initial broadcast not yet acknowledged by any peers)
Implementations
Sourceimpl MempoolEntry
impl MempoolEntry
Sourcepub fn into_model(self) -> Result<MempoolEntry, MempoolEntryError>
pub fn into_model(self) -> Result<MempoolEntry, MempoolEntryError>
Converts version specific type to a version nonspecific, more strongly typed type.