pub struct RawAddrManEntry {
pub address: String,
pub mapped_as: Option<u32>,
pub port: u16,
pub network: String,
pub services: u64,
pub time: i64,
pub source: String,
pub source_network: String,
pub source_mapped_as: Option<u32>,
}Expand description
An entry in the address manager table. Part of getrawaddrman.
The key in the parent map is formatted as “bucket/position” indicating the location in the relevant address manager table.
Field order matches Bitcoin Core’s RPC response definition.
Fields
address: StringThe address of the node.
mapped_as: Option<u32>Mapped AS (Autonomous System) number at the end of the BGP route to the peer. Only present if the -asmap config option is set.
port: u16The port number of the node.
network: StringThe network (ipv4, ipv6, onion, i2p, cjdns) of the address.
services: u64The services offered by the node.
time: i64The UNIX epoch time when the node was last seen.
source: StringThe address that relayed the address to us.
source_network: StringThe network (ipv4, ipv6, onion, i2p, cjdns) of the source address.
source_mapped_as: Option<u32>Mapped AS (Autonomous System) number at the end of the BGP route to the source. Only present if the -asmap config option is set.