pub struct ScanTxOutSetStart {
pub success: bool,
pub tx_outs: u64,
pub height: u64,
pub best_block: String,
pub unspents: Vec<ScanTxOutSetUnspent>,
pub total_amount: f64,
}Expand description
Result of JSON-RPC method scantxoutset.
scantxoutset “action” ( [scanobjects,…] )
Arguments:
- action (string, required) The action to execute
- scanobjects (json array, required) Array of scan objects
Fields
success: boolWhether the scan was completed.
tx_outs: u64The number of unspent transaction outputs scanned.
height: u64The block height at which the scan was done.
best_block: StringThe hash of the block at the tip of the chain.
unspents: Vec<ScanTxOutSetUnspent>The unspents.
total_amount: f64The total amount of all found unspent outputs in BTC.
Implementations
Sourceimpl ScanTxOutSetStart
impl ScanTxOutSetStart
Sourcepub fn into_model(self) -> Result<ScanTxOutSetStart, ScanTxOutSetError>
pub fn into_model(self) -> Result<ScanTxOutSetStart, ScanTxOutSetError>
Converts version specific type to a version nonspecific, more strongly typed type.