pub struct SignFail {
pub txid: String,
pub vout: u64,
pub script_sig: String,
pub sequence: u32,
pub error: String,
}Expand description
A script verification error. Part of signrawtransaction.
Fields
txid: StringThe hash of the referenced, previous transaction.
vout: u64The index of the output to spent and used as input.
script_sig: StringThe hex-encoded signature script.
sequence: u32Script sequence number.
error: StringVerification or signing error related to the input.
Implementations
Sourceimpl SignFail
impl SignFail
Sourcepub fn into_model(self) -> Result<SignFail, SignFailError>
pub fn into_model(self) -> Result<SignFail, SignFailError>
Converts version specific type to a version nonspecific, more strongly typed type.