pub struct Softfork {
pub type_: SoftforkType,
pub bip9: Option<Bip9SoftforkInfo>,
pub height: Option<i64>,
pub active: bool,
}Expand description
Softfork status. Part of getblockchaininfo.
Fields
type_: SoftforkTypeThe SoftforkType: one of “buried”, “bip9”.
bip9: Option<Bip9SoftforkInfo>The status of bip9 softforks (only for “bip9” type).
height: Option<i64>Height of the first block which the rules are or will be enforced (only for “buried” type, or “bip9” type with “active” status).
active: booltrue if the rules are enforced for the mempool and the next block.