pub struct SubmitPackageTxResultFees {
pub base_fee: f64,
pub effective_fee_rate: Option<f64>,
pub effective_includes: Option<Vec<String>>,
}Expand description
The fees included in the per-transaction result. Part of submitpackage.
Fields
base_fee: f64Transaction fee.
effective_fee_rate: Option<f64>The effective feerate.
Will be None if the transaction was already in the mempool. For example, the package
feerate and/or feerate with modified fees from the prioritisetransaction JSON-RPC method.
effective_includes: Option<Vec<String>>If Self::effective_fee_rate is provided, this holds the wtxid’s of the transactions
whose fees and vsizes are included in effective-feerate.
Implementations
Sourceimpl SubmitPackageTxResultFees
impl SubmitPackageTxResultFees
Sourcepub fn into_model(
self,
) -> Result<SubmitPackageTxResultFees, SubmitPackageTxResultFeesError>
pub fn into_model( self, ) -> Result<SubmitPackageTxResultFees, SubmitPackageTxResultFeesError>
Converts version specific type to a version in-specific, more strongly typed type.