ValidateAddress

Struct ValidateAddress 

pub struct ValidateAddress {
    pub is_valid: bool,
    pub address: String,
    pub script_pubkey: String,
    pub is_script: bool,
    pub is_witness: bool,
    pub witness_version: Option<i64>,
    pub witness_program: Option<String>,
}
Result of JSON-RPC method validateaddress.

validateaddress “address”

Return information about the given bitcoin address. DEPRECATION WARNING: Parts of this command have been deprecated and moved to getaddressinfo. Clients must transition to using getaddressinfo to access this information before upgrading to v0.18. The following deprecated fields have moved to getaddressinfo and will only be shown here with -deprecatedrpc=validateaddress: ismine, iswatchonly, script, hex, pubkeys, sigsrequired, pubkey, addresses, embedded, iscompressed, account, timestamp, hdkeypath, kdmasterkeyid.

Arguments:

  1. “address” (string, required) The bitcoin address to validate

Fields

is_valid: bool

If the address is valid or not. If not, this is the only property returned.

address: String

The bitcoin address validated.

script_pubkey: String

The hex encoded scriptPubKey generated by the address.

is_script: bool

If the key is a script.

is_witness: bool

If the address is a witness address.

witness_version: Option<i64>

The version number of the witness program.

witness_program: Option<String>

The hex value of the witness program.

Implementations

Source

impl ValidateAddress

pub fn into_model(self) -> Result<ValidateAddress, ValidateAddressError>

Converts version specific type to a version nonspecific, more strongly typed type.