pub struct GetTxOutSetInfoBlockInfo {
pub prevout_spent: Amount,
pub coinbase: Amount,
pub new_outputs_ex_coinbase: Amount,
pub unspendable: Amount,
pub unspendables: GetTxOutSetInfoUnspendables,
}Expand description
Detailed block-level info. Part of gettxoutsetinfo.
Fields
prevout_spent: AmountTotal amount of all prevouts spent in this block.
coinbase: AmountCoinbase subsidy amount of this block.
new_outputs_ex_coinbase: AmountTotal amount of new outputs created by this block.
unspendable: AmountTotal amount of unspendable outputs created in this block.
unspendables: GetTxOutSetInfoUnspendablesDetailed view of unspendable categories.